@@ -22,11 +22,11 @@ session <- function(session_id = NULL, term_id = NULL, date = NULL, extra_param
   filter_args <- {}
   
   if (!is.null(session_id)) {
-    filter_args <- c(filter_args, generate_filter("session_id", session_id))
+    filter_args <- c(filter_args, .generate_filter("session_id", session_id))
   }
   
   if (!is.null(term_id)) {
-    filter_args <- c(filter_args, generate_filter("term_id", term_id))
+    filter_args <- c(filter_args, .generate_filter("term_id", term_id))
   }
   
   if (!is.null(date)) {
@@ -46,7 +46,7 @@ session <- function(session_id = NULL, term_id = NULL, date = NULL, extra_param
   df <- legco_api("schedule", query, 10000, count, verbose)
   
   if (!count) {
-    colnames(df) <- unify_colnames(colnames(df)) # in utils-misc.R
+    colnames(df) <- .unify_colnames(colnames(df)) # in utils-misc.R
   }
   
   df
